==> ejc-bfyjerp-impl-3.0.0-20241107.070435-18-sources.jar: com/ejianc/business/project/bean/LeaveSiteEntity.java <==
package com.ejianc.business.project.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 项目基本信息管理-人员撤场
 * 
 * @author generator
 * 
 */
 @TableName("ejc_project_leave_site")
public class LeaveSiteEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; //编码
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目部Id
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部所属组织Id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织名称
    @TableField(value="on_site_employee_id")
    private Long onSiteEmployeeId; // 人员id
    @TableField(value="on_site_employee_name")
    private String onSiteEmployeeName; // 人员名称
    @TableField(value="on_site_employee_code")
    private String onSiteEmployeeCode; // 人员编码
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="on_site_post_id")
    private Long onSitePostId; // 驻场岗位id
    @TableField(value="on_site_post_name")
    private String onSitePostName; // 驻场岗位名称
    @TableField(value="daily_mny")
    private BigDecimal dailyMny; // 金额(天)
    @TableField(value="start_date")
    private Date startDate; // 开始时间
    @TableField(value="end_date")
    private Date endDate; // 开始时间
    @TableField(value="on_site_id")
    private Long onSiteId; // 驻场单id
    @TableField(value="on_site_days")
    private Integer onSiteDays; // 驻场天数
    @TableField(value="on_site_mny")
    private BigDecimal onSiteMny; // 驻场金额
    @TableField(value="employee_id")
    private Long employeeId; // 编制人员id
    @TableField(value="employee_name")
    private String employeeName; // 编制人员名称
    @TableField(value="engineering_type")
    private Long engineeringType; // 工程类型
    @TableField(value = "engineering_type_name")
    private String engineeringTypeName; //工程类型名称

    public Long getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(Long engineeringType) {
        this.engineeringType = engineeringType;
    }

    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getOnSiteEmployeeId() {
        return onSiteEmployeeId;
    }

    public void setOnSiteEmployeeId(Long onSiteEmployeeId) {
        this.onSiteEmployeeId = onSiteEmployeeId;
    }
    public String getOnSiteEmployeeName() {
        return onSiteEmployeeName;
    }

    public void setOnSiteEmployeeName(String onSiteEmployeeName) {
        this.onSiteEmployeeName = onSiteEmployeeName;
    }
    public String getOnSiteEmployeeCode() {
        return onSiteEmployeeCode;
    }

    public void setOnSiteEmployeeCode(String onSiteEmployeeCode) {
        this.onSiteEmployeeCode = onSiteEmployeeCode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public Long getOnSitePostId() {
        return onSitePostId;
    }

    public void setOnSitePostId(Long onSitePostId) {
        this.onSitePostId = onSitePostId;
    }
    public String getOnSitePostName() {
        return onSitePostName;
    }

    public void setOnSitePostName(String onSitePostName) {
        this.onSitePostName = onSitePostName;
    }
    public BigDecimal getDailyMny() {
        return dailyMny;
    }

    public void setDailyMny(BigDecimal dailyMny) {
        this.dailyMny = dailyMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Long getOnSiteId() {
        return onSiteId;
    }

    public void setOnSiteId(Long onSiteId) {
        this.onSiteId = onSiteId;
    }
    public Integer getOnSiteDays() {
        return onSiteDays;
    }

    public void setOnSiteDays(Integer onSiteDays) {
        this.onSiteDays = onSiteDays;
    }
    public BigDecimal getOnSiteMny() {
        return onSiteMny;
    }

    public void setOnSiteMny(BigDecimal onSiteMny) {
        this.onSiteMny = onSiteMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20241227.014805-87-sources.jar: com/ejianc/business/project/bean/LeaveSiteEntity.java <==
package com.ejianc.business.project.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 项目基本信息管理-人员撤场
 * 
 * @author generator
 * 
 */
 @TableName("ejc_project_leave_site")
public class LeaveSiteEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; //编码
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目部Id
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部所属组织Id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织名称
    @TableField(value="on_site_employee_id")
    private Long onSiteEmployeeId; // 人员id
    @TableField(value="on_site_employee_name")
    private String onSiteEmployeeName; // 人员名称
    @TableField(value="on_site_employee_code")
    private String onSiteEmployeeCode; // 人员编码
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="on_site_post_id")
    private Long onSitePostId; // 驻场岗位id
    @TableField(value="on_site_post_name")
    private String onSitePostName; // 驻场岗位名称
    @TableField(value="daily_mny")
    private BigDecimal dailyMny; // 金额(天)
    @TableField(value="start_date")
    private Date startDate; // 开始时间
    @TableField(value="end_date")
    private Date endDate; // 结束时间
    @TableField(value="on_site_id")
    private Long onSiteId; // 驻场单id
    @TableField(value="on_site_days")
    private Integer onSiteDays; // 驻场天数
    @TableField(value="on_site_mny")
    private BigDecimal onSiteMny; // 驻场金额
    @TableField(value="employee_id")
    private Long employeeId; // 编制人员id
    @TableField(value="employee_name")
    private String employeeName; // 编制人员名称
    @TableField(value="engineering_type")
    private Long engineeringType; // 工程类型
    @TableField(value = "engineering_type_name")
    private String engineeringTypeName; //工程类型名称

    public Long getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(Long engineeringType) {
        this.engineeringType = engineeringType;
    }

    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getOnSiteEmployeeId() {
        return onSiteEmployeeId;
    }

    public void setOnSiteEmployeeId(Long onSiteEmployeeId) {
        this.onSiteEmployeeId = onSiteEmployeeId;
    }
    public String getOnSiteEmployeeName() {
        return onSiteEmployeeName;
    }

    public void setOnSiteEmployeeName(String onSiteEmployeeName) {
        this.onSiteEmployeeName = onSiteEmployeeName;
    }
    public String getOnSiteEmployeeCode() {
        return onSiteEmployeeCode;
    }

    public void setOnSiteEmployeeCode(String onSiteEmployeeCode) {
        this.onSiteEmployeeCode = onSiteEmployeeCode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public Long getOnSitePostId() {
        return onSitePostId;
    }

    public void setOnSitePostId(Long onSitePostId) {
        this.onSitePostId = onSitePostId;
    }
    public String getOnSitePostName() {
        return onSitePostName;
    }

    public void setOnSitePostName(String onSitePostName) {
        this.onSitePostName = onSitePostName;
    }
    public BigDecimal getDailyMny() {
        return dailyMny;
    }

    public void setDailyMny(BigDecimal dailyMny) {
        this.dailyMny = dailyMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Long getOnSiteId() {
        return onSiteId;
    }

    public void setOnSiteId(Long onSiteId) {
        this.onSiteId = onSiteId;
    }
    public Integer getOnSiteDays() {
        return onSiteDays;
    }

    public void setOnSiteDays(Integer onSiteDays) {
        this.onSiteDays = onSiteDays;
    }
    public BigDecimal getOnSiteMny() {
        return onSiteMny;
    }

    public void setOnSiteMny(BigDecimal onSiteMny) {
        this.onSiteMny = onSiteMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    
}
